# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""update ingestion for transfer plugin

Revision ID: 3d0591e1b28e
Revises: 2d19b2a6e999
Create Date: 2021-11-04 11:51:09.385687

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "3d0591e1b28e"
down_revision = "2d19b2a6e999"
branch_labels = None
depends_on = None

ingest_cal_condor = """executable = ingest_cal.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/conveyor, nraorsync://$(SBIN_PATH)/ingest_envoy, nraorsync://$(SBIN_PATH)/ingest, nraorsync://$(SBIN_PATH)/calibration-table-collector.sh, nraorsync://{{spool_dir}}/metadata.json
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo CFLAGS=-I/usr/include/mysql LDFLAGS=-L/usr/lib64/mysql ORACLE_HOME=/home/ssa/share/oracle/instantclient_12_1 LD_LIBRARY_PATH=/home/ssa/share/oracle/instantclient_12_1 PATH=/bin:/usr/bin:$(PATH)/home/ssa/share/oracle/instantclient_12_1"

requirements = HasLustre == True

queue

"""

ingest_img_condor = """executable = ingest_image.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{spool_dir}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/conveyor, nraorsync://$(SBIN_PATH)/ingest_envoy, nraorsync://$(SBIN_PATH)/ingest, nraorsync://$(SBIN_PATH)/image-product-collector.sh, nraorsync://$(SPOOL_DIR)/metadata.json, nraorsync://$(SPOOL_DIR)/aux_image_metadata.json
+WantIOProxy = True

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

old_cal = """executable = ingest_cal.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/calibration-table-collector.sh, ./metadata.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo CFLAGS=-I/usr/include/mysql LDFLAGS=-L/usr/lib64/mysql ORACLE_HOME=/home/ssa/share/oracle/instantclient_12_1 LD_LIBRARY_PATH=/home/ssa/share/oracle/instantclient_12_1 PATH=/bin:/usr/bin:$(PATH)/home/ssa/share/oracle/instantclient_12_1"

requirements = HasLustre == True

queue
"""

old_img = """executable = ingest_image.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/image-product-collector.sh, ./metadata.json, ./aux_image_metadata.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{ingest_cal_condor}' WHERE filename='ingest_cal.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{ingest_img_condor}' WHERE filename='ingest_image.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_cal}' WHERE filename='ingest_cal.condor'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_img}' WHERE filename='ingest_image.condor'
            """
    )
