#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable=C0114, C0115, C0116, E0401, R0201, R0903, W0613, W0621, W1203
"""email column for qa_staff

Revision ID: c98733cfe926
Revises: 3b2996519a0f
Create Date: 2022-04-06 08:22:12.666711

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "c98733cfe926"
down_revision = "3b2996519a0f"
branch_labels = None
depends_on = None


def upgrade():
    op.add_column("qa_staff", sa.Column("email", sa.String, default=None))

    op.execute(
        """
        INSERT INTO notification_templates (name, description, template)
        VALUES ('aod_review', 'Email template for notifying the AOD of a product ready for review',
        'To: {{destination_email}}
Subject: NRAO Workspaces - Review products for #{{version.capability_request_id}}


    Dear AOD,

    A {{version.capability_name}} request #{{version.capability_request_id}}, version #{{version.version_number}}
    has passed initial QA and is ready to review.

    Best regards,
    NRAO Workspaces')
    """
    )

    op.execute(
        """
        INSERT INTO notification_templates (name, description, template)
        VALUES ('aod_revisit', 'Email template for notifying the DAs of the need to revisit a product',
        'To: {{destination_email}}
Subject: NRAO Workspaces - Revisit products of #{{version.capability_request_id}}


    Dear DAs,

    A {{version.capability_name}} request #{{version.capability_request_id}}, version #{{version.version_number}}
    has been returned to you for further revision.

    Best regards,
    NRAO Workspaces')
    """
    )

    op.execute(
        """UPDATE capability_state_machines SET machine_type='double_qa'
        WHERE capability_name IN ('std_calibration', 'std_cms_imaging')"""
    )


def downgrade():
    op.drop_colum("qa_staff", "email")

    op.execute(
        """
        DELETE FROM notification_templates WHERE name='aod_review'
        """
    )

    op.execute(
        """
        DELETE FROM notification_templates WHERE name='aod_revisit'
        """
    )

    op.execute(
        """
        UPDATE capability_state_machines SET machine_type='single_qa'
        WHERE capability_name IN ('std_calibration', 'std_cms_imaging')
        """
    )
